from .utils import *

def get_df(n, selection="01", **kwargs):
    if selection=="01":
        return get_df01(n,**kwargs)
    else:
        raise NotImplementedError("Selection not available")

def get_df01(n,**kwargs):
    df = {
        'x1': np.random.normal(0,1,size=(n,)),
        'x2': np.random.normal(10,1,size=(n,)),
        'x3': np.random.normal(5,4,size=(n,)),
        't1': np.random.choice([1,2], size=(n,)),
        't2': np.random.choice([3,4,5], size=(n,)),
        'target': np.zeros(shape=(n,)),
    }
    df['target'] = (df['t1']==1).astype(int) + (df['t2']==3).astype(int) + (df['x3']>6).astype(int) + (df['x2']<1.4).astype(int)
    df = pd.DataFrame(df)
    return df



import argparse

def test_dummy_df(parser):
    parser.add_argument('--n', default=77, type=int, help=None)
    args, unknown = parser.parse_known_args()
    kwargs = vars(args)  # is a dictionary    

    import kero
    df = kero.dummy.get_df(n, selection="01", **kwargs)
    print(df)


if __name__=='__main__':
    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawDescriptionHelpFormatter,
        description=None)
    parser.add_argument('--TOGGLES', default='1', type=str, help=None)
    # parser.add_argument('-m','--mode', default=None, type=str, help=None)
    # parser.add_argument('--id', nargs='+', default=['a','b']) # for list args
    args, unknown = parser.parse_known_args()
    kwargs = vars(args)  # is a dictionary    

    TOGGLES = kwargs['TOGGLES']
    if TOGGLES[0] == '1':
        test_dummy_df(parser)
